@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.8.9"
+    version = "1.9.0"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -161,7 +161,11 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
             }
 
         }
-        # 0 - 状态为未解决，并且次数大于设定值，才告警通知，并且分配为空
-        if group.status == 0 and group.times_seen > number_alarm and not bool(event.data):
+        # 0 - 状态为未解决，并且次数大于设定值，才告警通知
+        if group.status == 0 and group.times_seen:
             for webhook_url in self.get_webhook_urls(group.project):
                 requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
+
+        # 分配人员或清除人员均不发出告警
+        if not bool(event.data) or bool(event.data):
+            pass
